==> campsite-2.5.1.tar.gz: campsite/implementation/management/priv/lang/de/users.php <==
<?php
regGS("65 or over", "65 oder älter");
regGS("User may translate articles", "User darf Artikel übersetzen");
regGS("User may move articles", "User darf Artikel verschieben");
regGS("User may find and replace", "User darf Suchen und Ersetzen");
regGS("User may change system preferences", "User darf Systemeinstellungen ändern");
regGS("User may attach topics to articles", "User darf Themen mit Artikeln verknüpfen");
regGS("User may attach images to articles", "User darf Bilder zu Artikeln hinzufügen");
regGS("User may add special characters", "User darf Sonderzeichen einfügen");
regGS("Reset search form", "Formular zurück setzen");
regGS("That user name already exists, please choose a different login name.", "Der Username existiert bereits, bitte einen anderen Loginnamen wählen.");
regGS("User may delete article attachments", "User darf Artikelanhänge löschen");
regGS("User may change article attachments", "User darf Artikelanhänge verändern");
regGS("User may add article attachments", "User darf Artikelanhänge hinzufügen");
regGS("Staff management", "Personal Management");
regGS("Subscriber management", "Abonnementen Management");
regGS("Account Name", "Name des Kontos");
regGS("Full Name", "Vollständiger Name");
regGS("Delete user $1", "BenutzerInn $1 löschen");
regGS("User list is empty.", "Userliste ist leer.");
regGS("You do not have the right to create user accounts.", "Keine Berechtigung Benutzerkonten zu erstellen");
regGS("Title", "Titel");
regGS("Gender", "Geschlecht");
regGS("Mr.", "Herr");
regGS("Mrs.", "Frau");
regGS("Ms.", "Frau");
regGS("Dr.", "Dr.");
regGS("Male", "männlich");
regGS("Female", "weiblich");
regGS("under 18", "unter 18");
regGS("Age", "Alter");
regGS("Confirm password", "Passwort bestätigen");
regGS("E-Mail", "E-Mail");
regGS("City", "Stadt");
regGS("Street Address", "Strasse");
regGS("Postal Code", "Postleitzahl");
regGS("State", "Staat");
regGS("Phone", "Telefonnummer");
regGS("Fax", "Fax");
regGS("Contact Person", "Kontaktperson");
regGS("Second Phone", "Zweite Telefonnummer");
regGS("Employer", "Arbeitgeber");
regGS("Employer Type", "Arbeitsfeld");
regGS("Corporate", "Firma");
regGS("Non-Governmental Organisation", "Nichtstaatliche Organisation");
regGS("Government Agency", "Staatliche Stelle");
regGS("Academic", "Akademiker");
regGS("Media", "Medien");
regGS("Position", "Stellung");
regGS("Show more user details", "Mehr Userdetails anzeigen");
regGS("Hide user details", "Userdetails ausblenden");
regGS("You must select a $1", "Bitte ein $1 auswählen");
regGS("The password must be at least 6 characters long and both passwords should match.", "Das Passwort muss mindestens 6 Stellen lang sein und beide Passwörter müssen übereinstimmen");
regGS("The user account could not be created.", "Benutzerkonto konnte nicht erstellt werden");
regGS("User account $1 was created successfully.", "User Konto $1 wurder erfolgreich erstellt.");
regGS("Click here to change password", "Hier klicken, um Kennwort zu ändern");
regGS("Old Password", "Altes Kennwort");
regGS("You do not have the right to change user account permissions.", "Keine Berechtigung Benutzerkontogenehmigung zu ändern");
regGS("Permissions for $1 changed", "Genehmigung für $1 geändert");
regGS("You do not have the right to change user account information.", "Keine Berechtigung Benutzerkontoinformation zu ändern");
regGS("Click here to customize user permissions", "Hier klicken, um Userrechte zu ändern");
regGS("Click here to use existing user type permissions (discard customization)", "Hier klicken, um bestehende Typen von Zugriffsrechten zu benutzen (Keine individuellen Einstellungen)");
regGS("Click here to leave password unchanged", "Hier klicken, um Kennwort nicht zu ändern");
regGS("User account information changed for $1", "Benutzerkontoinformation für $1 wurde geändert");
regGS("The password you typed is incorrect.", "Das eingegebene Passwort ist falsch");
regGS("You do not have the right to delete user accounts.", "Keine Berechtigung Benutzerkonten zu löschen");
regGS("Are you sure you want to delete the user account $1 ?", "Benutzerkonto $1 wirklich löschen?");
regGS("User account $1 was deleted successfully.", "Userkonto $1 wurde erfolgreich erstellt.");
regGS("User IP access list management", "Zugang der Benutzer-IPs managen");
regGS("No records.", "Keine Eintragungen");
regGS("Start IP", "IP starten");
regGS("Number of addresses", "Anzahl der Adressen");
regGS("The IP Group $1 has been created.", "IP-Gruppe $1 wurde erstellt");
regGS("There was an error creating the IP address group.", "Fehler beim Erstellen der IP Adressgruppe.");
regGS("Are you sure you want to delete the IP Group $1?", "IP-Gruppe $1 wirklich löschen");
regGS("The IP address group $1 has been deleted.", "IP-Gruppe $1 wurde gelöscht");
regGS("User '$1' information was changed successfully.", "Userinformation für '$1' erfolgreich verändert.");
regGS("IP address", "IP Adresse");
regGS("fill in from left to right at least one input box", "Von links nach rechts mindestens eine Eingabe vornehmen");
regGS("User Type", "Usertyp");
regGS("You must input a valid EMail address.", "Eine gültige E-Mailadresse muss angegeben werden.");
regGS("The confirm password must be at least 6 characters long and both passwords should match.", "Das Kennwort muss mindestens 6 Zeichen lang sein und beide müssen übereinstimmen.");
regGS("You must input a number between 0 and 255 into the Start IP address' $1 field.", "In das Start IP Adressenfeld $1 muss eine Zahl zwischen 0 und 255 eingegeben werden.");
regGS("Delete subscriptions to $1", "Abonnements von $1 löschen");
regGS("Change user account information", "Benutzerkontoinformation ändern");
regGS("The IP address group $1:$2 conflicts with another existing group.", "Konflikt zwischen der IP Adressgruppe $1:$2 und einer anderen Gruppe.");
regGS("Creation Date", "Erstellungsdatum");
regGS("User management", "BenutzerInnen managen");
regGS("Set", "Auswählen");
regGS("Update", "Aktualisieren");
regGS("Rights", "Berechtigungen");
regGS("IP Access", "IP Zugang");
regGS("User Name", "Benutzername");
regGS("Staff", "Personal");
regGS("Adding new user account", "Neues Benutzerkonto hinzufügen");
regGS("You must select an user type.", "Bitte Benutzertyp auswählen");
regGS("The user account $1 has been created.", "Benutzerkonto $1 wurde erstellt");
regGS("Please check if an account with the same user name does not already exist.", "Bitte überprüfen, ob ein Konto mit demselben Benutzername existiert");
regGS("Change password", "Benutzerpasswort ändern");
regGS("You do not have the right to change user passwords.", "Keine Berechtigung Benutzerpasswörter zu ändern");
regGS("Changing user password", "Passwort wird geändert");
regGS("The password could not be changed.", "Das Passwort konnte nicht geändert werden");
regGS("The password has been changed.", "Passwort wurde geändert");
regGS("User may manage templates", "BenutzerIn kann Templates managen");
regGS("User may add/change country entries", "BenutzerIn kann Ländereinträge hinzufügen/ändern");
regGS("Edit user account permissions", "Benutzerkontogenehmigung bearbeiten");
regGS("This user account does not have permissions information.", "Dieses Benutzerkonto hat keine Genehmigungsinformationen");
regGS("Updating user account permissions", "Benutzerkontogenehmigung wird aktualisiert");
regGS("User account permissions have been successfuly updated.", "Benutzerkontogenehmigung erfolgreich aktualisiert");
regGS("User account permissions could not be updated.", "Benutzerkontogenehmigung konnte nicht aktualisiert werden");
regGS("Changing user account information", "Benutzerkontoinformation wird geändert");
regGS("User account information has been changed.", "Benutzerkontoinformation geändert");
regGS("User account information could not be changed.", "Benutzerkontoinformation konnte nicht geändert werden");
regGS("Old password", "Altes Passwort");
regGS("New password", "Neues Passwort");
regGS("Confirm new password", "Neues Passwort bestätogen");
regGS("Changing your password", "Passwort wird geändert");
regGS("User $1 changed his password", "BenutzerIn $1 hat Passwort geändert");
regGS("Delete user account", "Benutzerkonto löschen");
regGS("Deleting user account", "Benutzerkonto wird gelöscht");
regGS("The user account $1 could not be deleted.", "Benutzerkonto $1 konnte nicht gelöscht werden");
regGS("No such user.", "BenutzerIn existiert nicht");
regGS("Delete IP Group $1", "IP-Gruppe $1 löschen");
regGS("IP Access List", "IP-Zugangsliste");
regGS("Adding new IP Group", "Neue IP-Gruppe wird hinzugeführt");
regGS("The IP Group could not be created.", "IP-Gruppe konnte nicht erstellt werden");
regGS("Please check if an account with the same IP Group does not already exist.", "Bitte überprüfen, ob bereits ein Konto mit derselben IP-Gruppe existiert");
regGS("Delete IP Group", "IP-Gruppe löschen");
regGS("You do not have the right to delete IP Groups.", "Keine Berechtigung IP-Gruppen zu löschen");
regGS("No such IP Group.", "IP-Gruppe nicht vorhanden");
regGS("Deleting IP Group", "IP-Gruppe wird gelöscht");
regGS("The IP Group could not be deleted.", "IP-Gruppe konnte nicht gelöscht werden");
?>

==> campsite-2.6.6.tar.gz: campsite/implementation/management/priv/lang/de/users.php <==
<?php 
regGS("User may moderate comments", "");
regGS("User may enable comments", "");
regGS("65 or over", "65 oder älter");
regGS("User may translate articles", "User darf Artikel übersetzen");
regGS("User may move articles", "User darf Artikel verschieben");
regGS("User may find and replace", "User darf Suchen und Ersetzen");
regGS("User may change system preferences", "User darf Systemeinstellungen ändern");
regGS("User may attach topics to articles", "User darf Themen mit Artikeln verknüpfen");
regGS("User may attach images to articles", "User darf Bilder zu Artikeln hinzufügen");
regGS("User may add special characters", "User darf Sonderzeichen einfügen");
regGS("Reset search form", "Formular zurück setzen");
regGS("That user name already exists, please choose a different login name.", "Der Username existiert bereits, bitte einen anderen Loginnamen wählen.");
regGS("User may delete article attachments", "User darf Artikelanhänge löschen");
regGS("User may change article attachments", "User darf Artikelanhänge verändern");
regGS("User may add article attachments", "User darf Artikelanhänge hinzufügen");
regGS("Staff management", "Personal Management");
regGS("Subscriber management", "Abonnementen Management");
regGS("Account Name", "Name des Kontos");
regGS("Full Name", "Vollständiger Name");
regGS("Delete user $1", "BenutzerInn $1 löschen");
regGS("User list is empty.", "Userliste ist leer.");
regGS("You do not have the right to create user accounts.", "Keine Berechtigung Benutzerkonten zu erstellen");
regGS("Title", "Titel");
regGS("Gender", "Geschlecht");
regGS("Mr.", "Herr");
regGS("Mrs.", "Frau");
regGS("Ms.", "Frau");
regGS("Dr.", "Dr.");
regGS("Male", "männlich");
regGS("Female", "weiblich");
regGS("under 18", "unter 18");
regGS("Age", "Alter");
regGS("Confirm password", "Passwort bestätigen");
regGS("E-Mail", "E-Mail");
regGS("City", "Stadt");
regGS("Street Address", "Strasse");
regGS("Postal Code", "Postleitzahl");
regGS("State", "Staat");
regGS("Phone", "Telefonnummer");
regGS("Fax", "Fax");
regGS("Contact Person", "Kontaktperson");
regGS("Second Phone", "Zweite Telefonnummer");
regGS("Employer", "Arbeitgeber");
regGS("Employer Type", "Arbeitsfeld");
regGS("Corporate", "Firma");
regGS("Non-Governmental Organisation", "Nichtstaatliche Organisation");
regGS("Government Agency", "Staatliche Stelle");
regGS("Academic", "Akademiker");
regGS("Media", "Medien");
regGS("Position", "Stellung");
regGS("Show more user details", "Mehr Userdetails anzeigen");
regGS("Hide user details", "Userdetails ausblenden");
regGS("You must select a $1", "Bitte ein $1 auswählen");
regGS("The password must be at least 6 characters long and both passwords should match.", "Das Passwort muss mindestens 6 Stellen lang sein und beide Passwörter müssen übereinstimmen");
regGS("The user account could not be created.", "Benutzerkonto konnte nicht erstellt werden");
regGS("User account $1 was created successfully.", "User Konto $1 wurder erfolgreich erstellt.");
regGS("Click here to change password", "Hier klicken, um Kennwort zu ändern");
regGS("Old Password", "Altes Kennwort");
regGS("You do not have the right to change user account permissions.", "Keine Berechtigung Benutzerkontogenehmigung zu ändern");
regGS("Permissions for $1 changed", "Genehmigung für $1 geändert");
regGS("You do not have the right to change user account information.", "Keine Berechtigung Benutzerkontoinformation zu ändern");
regGS("Click here to customize user permissions", "Hier klicken, um Userrechte zu ändern");
regGS("Click here to use existing user type permissions (discard customization)", "Hier klicken, um bestehende Typen von Zugriffsrechten zu benutzen (Keine individuellen Einstellungen)");
regGS("Click here to leave password unchanged", "Hier klicken, um Kennwort nicht zu ändern");
regGS("User account information changed for $1", "Benutzerkontoinformation für $1 wurde geändert");
regGS("The password you typed is incorrect.", "Das eingegebene Passwort ist falsch");
regGS("You do not have the right to delete user accounts.", "Keine Berechtigung Benutzerkonten zu löschen");
regGS("Are you sure you want to delete the user account $1 ?", "Benutzerkonto $1 wirklich löschen?");
regGS("User account $1 was deleted successfully.", "Userkonto $1 wurde erfolgreich erstellt.");
regGS("User IP access list management", "Zugang der Benutzer-IPs managen");
regGS("No records.", "Keine Eintragungen");
regGS("Start IP", "IP starten");
regGS("Number of addresses", "Anzahl der Adressen");
regGS("The IP Group $1 has been created.", "IP-Gruppe $1 wurde erstellt");
regGS("There was an error creating the IP address group.", "Fehler beim Erstellen der IP Adressgruppe.");
regGS("Are you sure you want to delete the IP Group $1?", "IP-Gruppe $1 wirklich löschen");
regGS("The IP address group $1 has been deleted.", "IP-Gruppe $1 wurde gelöscht");
regGS("User '$1' information was changed successfully.", "Userinformation für '$1' erfolgreich verändert.");
regGS("IP address", "IP Adresse");
regGS("fill in from left to right at least one input box", "Von links nach rechts mindestens eine Eingabe vornehmen");
regGS("User Type", "Usertyp");
regGS("The confirm password must be at least 6 characters long and both passwords should match.", "Das Kennwort muss mindestens 6 Zeichen lang sein und beide müssen übereinstimmen.");
regGS("You must input a number between 0 and 255 into the Start IP address' $1 field.", "In das Start IP Adressenfeld $1 muss eine Zahl zwischen 0 und 255 eingegeben werden.");
regGS("Delete subscriptions to $1", "Abonnements von $1 löschen");
regGS("Change user account information", "Benutzerkontoinformation ändern");
regGS("The IP address group $1:$2 conflicts with another existing group.", "Konflikt zwischen der IP Adressgruppe $1:$2 und einer anderen Gruppe.");
regGS("Creation Date", "Erstellungsdatum");
regGS("User management", "BenutzerInnen managen");
regGS("Set", "Auswählen");
regGS("Update", "Aktualisieren");
regGS("Rights", "Berechtigungen");
regGS("IP Access", "IP Zugang");
regGS("User Name", "Benutzername");
regGS("Staff", "Personal");
regGS("Adding new user account", "Neues Benutzerkonto hinzufügen");
regGS("You must select an user type.", "Bitte Benutzertyp auswählen");
regGS("The user account $1 has been created.", "Benutzerkonto $1 wurde erstellt");
regGS("Please check if an account with the same user name does not already exist.", "Bitte überprüfen, ob ein Konto mit demselben Benutzername existiert");
regGS("Change password", "Benutzerpasswort ändern");
regGS("You do not have the right to change user passwords.", "Keine Berechtigung Benutzerpasswörter zu ändern");
regGS("Changing user password", "Passwort wird geändert");
regGS("The password could not be changed.", "Das Passwort konnte nicht geändert werden");
regGS("The password has been changed.", "Passwort wurde geändert");
regGS("User may manage templates", "User kann Templates verwalten");
regGS("User may add/change country entries", "User kann Ländereinstellungen hinzufügen und ändern");
regGS("Edit user account permissions", "Benutzerkontogenehmigung bearbeiten");
regGS("This user account does not have permissions information.", "Dieses Benutzerkonto hat keine Genehmigungsinformationen");
regGS("Updating user account permissions", "Benutzerkontogenehmigung wird aktualisiert");
regGS("User account permissions have been successfuly updated.", "Benutzerkontogenehmigung erfolgreich aktualisiert");
regGS("User account permissions could not be updated.", "Benutzerkontogenehmigung konnte nicht aktualisiert werden");
regGS("Changing user account information", "Benutzerkontoinformation wird geändert");
regGS("User account information has been changed.", "Benutzerkontoinformation geändert");
regGS("User account information could not be changed.", "Benutzerkontoinformation konnte nicht geändert werden");
regGS("Old password", "Altes Passwort");
regGS("New password", "Neues Passwort");
regGS("Confirm new password", "Neues Passwort bestätogen");
regGS("Changing your password", "Passwort wird geändert");
regGS("User $1 changed his password", "BenutzerIn $1 hat Passwort geändert");
regGS("Delete user account", "Benutzerkonto löschen");
regGS("Deleting user account", "Benutzerkonto wird gelöscht");
regGS("The user account $1 could not be deleted.", "Benutzerkonto $1 konnte nicht gelöscht werden");
regGS("No such user.", "BenutzerIn existiert nicht");
regGS("Delete IP Group $1", "IP-Gruppe $1 löschen");
regGS("IP Access List", "IP-Zugangsliste");
regGS("Adding new IP Group", "Neue IP-Gruppe wird hinzugeführt");
regGS("The IP Group could not be created.", "IP-Gruppe konnte nicht erstellt werden");
regGS("Please check if an account with the same IP Group does not already exist.", "Bitte überprüfen, ob bereits ein Konto mit derselben IP-Gruppe existiert");
regGS("Delete IP Group", "IP-Gruppe löschen");
regGS("You do not have the right to delete IP Groups.", "Keine Berechtigung IP-Gruppen zu löschen");
regGS("No such IP Group.", "IP-Gruppe nicht vorhanden");
regGS("Deleting IP Group", "IP-Gruppe wird gelöscht");
regGS("The IP Group could not be deleted.", "IP-Gruppe konnte nicht gelöscht werden");
regGS("User may add/change publications", "BenutzerIn kann Publikationen hinzufügen / ändern");
regGS("Invalid value of user type parameter", "Ungültiger Wert für Nutzertyp");
regGS("User may delete publications", "BenutzerIn kann Publikationen löschen");
regGS("User may add/change issues", "BenutzerIn kann Ausgaben hinzufügen / ändern");
regGS("User may delete issues", "BenutzerIn kann Ausgaben löschen");
regGS("User may add/change sections", "BenutzerIn kann Rubriken hinzufügen / ändern");
regGS("User may delete sections", "BenutzerIn kann Abschnitte löschen");
regGS("User may add articles", "BenutzerIn kann Artikel hinzufügen");
regGS("User may change articles", "BenutzerIn kann Artikel hinzufügen");
regGS("User may delete articles", "BenutzerIn kann Artikel löschen");
regGS("User may add images", "BenutzerIn kann Bilder hinzufügen");
regGS("User may change images", "BenutzerIn kann Bilder ändern");
regGS("User may delete images", "BenutzerIn kann Bilder löschen");
regGS("User may delete templates", "BenutzerIn kannTemplates löschen");
regGS("User may add/change staff accounts and passwords", "User kann Personalkonten und Kennwörter hinzufügen und ändern");
regGS("User may add/change subscribers accounts and passwords", "User kann Abonnementenkonten und Kennwörter hinzufügen und ändern");
regGS("User may delete staff accounts", "User kann Personalkonten löschen");
regGS("User may manage user subscriptions", "BenutzerIn kann Abonnement managen");
regGS("User may manage account types", "BenutzerIn kann Profiltypen managen");
regGS("User may add/change article types", "BenutzerIn kann Artikeltypen hinzufügen / ändern");
regGS("User may delete article types", "BenutzerIn kann Artikeltypen löschen");
regGS("User may add languages and manage language information", "BenutzerIn kann Sprachen hinzufügen und Sprachinformationen managen");
regGS("User may delete languages", "BenutzerIn kann Sprachen löschen");
regGS("User may view audit logs", "BenutzerIn kann Log-Files betrachten");
regGS("User may delete country entries", "BenutzerIn  kann Lädereintragungen löschen");
regGS("User may manage localizer", "BenutzerIn kann Interface lokalisieren");
regGS("User may publish articles", "BenutzerIn kann Artikel veröffentlichen");
regGS("User may manage topics", "BenutzerIn kann Themen managen");
regGS("User may use bold", "User darf Text fetten");
regGS("User may use italic", "User darf Text kursiv stellen");
regGS("User may use underline", "User darf Text unterstreichen");
regGS("User may use strikethrough", "User darf Text durchstreichen");
regGS("User may change text alignment", "User darf Textausrichtung ändern");
regGS("User may copy, cut, and paste", "User darf Text kopieren, ausschneiden und einfügen");
regGS("User may undo/redo", "User darf Aktionen rückgängig machen und wieder herstellen");
regGS("User may change text direction", "User kann Textrichtung ändern");
regGS("User may set indents", "User darf Einschübe vornehmen");
regGS("User may add links", "User darf Links einfügen");
regGS("User may add subheads", "User darf Zwischenüberschriften einfügen");
regGS("User may insert images", "User darf Bilder einfügen");
regGS("User may view the HTML source", "User darf HTML Quellcode einsehen");
regGS("User may enlarge the editor", "User darf den Editor vergrößern");
regGS("User may change the font face", "User darf den Zeichensatz verändern");
regGS("User may change the font size", "User darf die Zeichengröße verändern");
regGS("User may create bulleted lists", "User darf unnummerierte Aufzählungen einrichten");
regGS("User may create numbered lists", "User darf nummerierte Aufzählungen einrichten");
regGS("User may insert tables", "User darf Tabellen einfügen");
regGS("User may insert horizontal rules", "User darf horizontale Linien einfügen");
regGS("User may change the font color", "User darf die Zeichenfarbe verändern");
regGS("User may use superscripts", "User darf Zeichen hochstellen");
regGS("User may use subscripts", "User darf Zeichen in Kleinschrift umwandeln");
regGS("User may restart the template engine", "User darf das Template-Engine neustarten");
regGS("Miscellaneous", "Verschiedenes");
regGS("Staff/Subscribers Management", "Personal / Abonnementen verwalten");
regGS("Editor Basic Settings", "Editor Voreinstellungen");
regGS("Editor Advanced Font Settings", "Editor Einstellungen für Zeichensätze");
regGS("Editor Table Settings", "Editor Einstellungen für Tabellen");
regGS("Administrative tasks", "Administrator Aufgaben");
regGS("User will be notified on several events", "BenutzerIn wird zu mehreren Anlässen benachrichtigt");
regGS("Paid", "Bezahlt");
regGS("No subscriptions.", "Keine Abonnements");
regGS("Editor Miscellaneous Settings", "Übrige Editor Einstellungen");
regGS("No such user account.", "Benutzerkonto nicht vorhanden");
?>
